import { login } from '../api/auth';
import router from '@/router';

const SetAuthJWT = 'SetAuthJWT';
const RemoveAuthJWT = 'RemoveAuthJWT';

export const authDataMutation = {
  SetAuthJWT,
  RemoveAuthJWT
};

const Login = 'Login';
const Logout = 'Logout';

export const authDataAction = {
  Login,
  Logout
};
/**
 * @type {import('vuex/types/index').Module<{authJWT:string}>}
 */
const authData = {
  state: {
    authJWT: '',
    isAdmin: false,
    name: '',
    level: 0
  },
  mutations: {
    /**
     * @param {{authJWT:string}} payload
     */
    [SetAuthJWT](state, payload) {
      state.authJWT = payload.authJWT;
      const info = JSON.parse(atob(payload.authJWT.split('.')[1]));
      state.isAdmin = info.roles === 'Admin';
      state.name = info.UserId;
      state.level = +info.level;
    },
    [RemoveAuthJWT](state, payload) {
      state.authJWT = '';
      state.isAdmin = false;
      state.name = '';
    }
  },
  actions: {
    async [Login]({ commit, dispatch }, payload) {
      const { data } = await login({
        Account: payload.Account,
        Password: payload.Password
      });
      if (data.Success) {
        commit(SetAuthJWT, { authJWT: data.Data });
        localStorage.setItem('authJWT', data.Data);
      }
      return data;
    },
    async [Logout]({ commit, dispatch }, payload) {
      commit(RemoveAuthJWT);
      localStorage.removeItem('authJWT');
      router.push('/login');
      return true;
    }
  }
};

export { authData };
